# 服务部署Helm Chart安装指南

本文档提供了使用此Helm Chart部署服务的详细步骤。

## 安装前准备

1. 确保已安装Helm 3.2.0+
2. 确保有权限访问Kubernetes集群
3. 准备好自定义的values.yaml文件

## 基本安装

使用默认配置安装Chart:

```bash
helm install my-release ./chart
```

## 使用自定义配置安装

1. 创建自定义values文件，例如`my-values.yaml`
2. 编辑配置文件设置所需参数
3. 安装Chart:

```bash
helm install my-release ./chart -f my-values.yaml
```

## 常用配置示例

### 部署简单服务

```yaml
service:
  name: my-app
  image: myapp:1.0.0
  port: 8080
```

### 部署带环境变量的服务

```yaml
service:
  name: my-app
  image: myapp:1.0.0
  port: 8080

env:
  - name: ENV
    value: production
  - name: DEBUG
    value: "false"
```

### 暴露服务到内网

```yaml
serviceConfig:
  exposeToIntranet: true
```

### 禁用Ingress

```yaml
ingress:
  enabled: false
```

## 验证安装

安装后，使用以下命令验证部署是否成功：

```bash
# 检查Pod是否正常运行
kubectl get pods -l app=my-app -n app

# 检查Service是否创建成功
kubectl get svc -n app

# 如果启用了Ingress，检查Ingress是否创建成功
kubectl get ingress -n app
```

## 卸载

使用以下命令卸载Chart:

```bash
helm uninstall my-release
```

## 故障排除

如果遇到部署问题，请尝试：

1. 检查Pod状态和日志
   ```bash
   kubectl get pods -n app
   kubectl logs <pod-name> -n app
   ```

2. 检查服务状态
   ```bash
   kubectl describe svc <service-name> -n app
   ```

3. 检查Ingress状态
   ```bash
   kubectl describe ingress <ingress-name> -n app
   ``` 