# 服务部署Helm Chart

这个Helm Chart用于快速部署服务到Kubernetes集群。

## 前提条件

- Kubernetes 1.19+
- Helm 3.2.0+

## 安装Chart

```bash
# 使用默认配置安装
helm install my-release ./chart

# 使用自定义values文件安装
helm install my-release ./chart -f values-custom.yaml

# 使用--set覆盖单个配置
helm upgrade --install test-ng -n app ./chart --set service.name=test-ng --set service.image=nginx:latest --set service.port=80 --set ingress.enabled=true --set ingress.host=test-ng.ai-native.glm.ai 
```

## 卸载Chart

```bash
helm uninstall my-release
```

## 配置参数

以下表格列出了此Chart的可配置参数及其默认值。

| 参数 | 描述 | 默认值 |
|------|------|--------|
| `service.name` | 服务名称 | `my-service` |
| `service.image` | 服务镜像 | `nginx:latest` |
| `service.port` | 服务端口 | `8080` |
| `service.replicas` | 服务副本数 | `1` |
| `service.namespace` | 服务部署的命名空间 | `app` |
| `service.imagePullPolicy` | 镜像拉取策略 | `IfNotPresent` |
| `service.imagePullSecrets` | 镜像拉取密钥 | `[{name: uhub}]` |
| `resources.enabled` | 是否启用资源限制 | `false` |
| `resources.limits.cpu` | CPU资源限制 | `1` |
| `resources.limits.memory` | 内存资源限制 | `1Gi` |
| `resources.requests.cpu` | CPU资源请求 | `500m` |
| `resources.requests.memory` | 内存资源请求 | `512Mi` |
| `env` | 环境变量列表 | `[]` |
| `ingress.enabled` | 是否启用Ingress | `true` |
| `ingress.className` | Ingress类名 | `ack-nginx-private` |
| `ingress.host` | 访问域名（必须是ai-native.glm.ai的子域） | `myservice.ai-native.glm.ai` |
| `ingress.tls.enabled` | 是否启用TLS | `true` |
| `ingress.tls.secretName` | TLS密钥名称 | `ai-native-glm-ai-tls` |
| `serviceConfig.exposeToIntranet` | 是否暴露到内网 | `false` |
| `serviceConfig.annotations` | 内网LoadBalancer注解 | 见values.yaml |

## 示例

请参考`values-example.yaml`文件获取完整的配置示例。 